@@ -26,7 +26,7 @@ class SelectCommand(BaseCommand):
             matches = [
                 bond
                 for bond in BondDatabase.get_bonds()
-                if bond.startswith(args.bond_id)
+                if bond.lower().startswith(args.bond_id.lower())
             ]
             if len(matches) == 0:
                 proceed = input(
@@ -36,10 +36,9 @@ class SelectCommand(BaseCommand):
                 if proceed.lower() == "y":
                     bond_id = args.bond_id
                 else:
-                    print(
+                    raise SystemExit(
                         "Aborting. Try 'bond discover' on the same network as your Bond"
                     )
-                    exit(1)
             if len(matches) == 1:
                 bond_id = matches[0]
             if len(matches) > 1:
@@ -57,7 +56,7 @@ class SelectCommand(BaseCommand):
             print("Selected Bond: %s" % BondDatabase().get("selected_bondid"))
             token = check_unlocked_token()
         elif args.clear:
-            BondDatabase.pop("selected_bondid", None)
+            BondDatabase().pop("selected_bondid", None)
             print("Cleared selected Bond")
 
 
